pub struct LearningEpisode {
pub id: Uuid,
pub intent_id: Uuid,
pub plan_id: Uuid,
pub predicted_outcome: String,
pub actual_outcome: Option<String>,
pub run_status: Option<String>,
pub prediction_error: Option<PredictionError>,
pub adversarial_signals: Vec<AdversarialContext>,
pub lessons: Vec<Lesson>,
}Expand description
Full record of a planning-to-outcome episode. Links intent, plan, predicted outcomes, governed business outcomes, engine run status, prediction errors, adversarial signals, and extracted lessons. Every field traces to converge Facts or run envelopes.
Fields
id: Uuidintent_id: Uuidplan_id: Uuidpredicted_outcome: Stringactual_outcome: Option<String>run_status: Option<String>prediction_error: Option<PredictionError>adversarial_signals: Vec<AdversarialContext>lessons: Vec<Lesson>Trait Implementations
Sourceimpl Clone for LearningEpisode
impl Clone for LearningEpisode
Sourcefn clone(&self) -> LearningEpisode
fn clone(&self) -> LearningEpisode
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LearningEpisode
impl Debug for LearningEpisode
Sourceimpl<'de> Deserialize<'de> for LearningEpisode
impl<'de> Deserialize<'de> for LearningEpisode
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<LearningEpisode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<LearningEpisode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for LearningEpisode
impl Serialize for LearningEpisode
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more